CURRENT_FORMAT_VERSION = 18
SUPPORTED_VERSIONS = (17, 18, 19)
faction_mapping = {
    0: 'DE',
    1: 'FR',
    2: 'IO',
    3: 'NX',
    4: 'PZ',
    5: 'SI',
    6: 'BW',
    9: 'MT',
    'DE': 0,
    'FR': 1,
    'IO': 2,
    'NX': 3,
    'PZ': 4,
    'SI': 5,
    'BW': 6,
    'MT': 9,
}
